@@ -1,8 +1,11 @@
 import sys
 
+import django
 import pytest
 from django.urls import reverse
 
+pytest.DJANGO41 = django.VERSION[0:2] == (4, 1)
+
 
 def pytest_configure(config):
     sys._called_from_pytest = True
